summaryrefslogtreecommitdiffstats
path: root/ipatests/test_webui
diff options
context:
space:
mode:
authorPetr Vobornik <pvoborni@redhat.com>2013-10-17 10:52:59 +0200
committerMartin Kosek <mkosek@redhat.com>2014-01-21 12:04:02 +0100
commit9a7e65100c4d193248ef19d5a79300e14c99fabc (patch)
tree6a4158a7848b4960f3ea102bc028d6f1bcda5824 /ipatests/test_webui
parenta85cda36070bb7279e1248342b8eb1b1e19a12a5 (diff)
downloadfreeipa-9a7e65100c4d193248ef19d5a79300e14c99fabc.tar.gz
freeipa-9a7e65100c4d193248ef19d5a79300e14c99fabc.tar.xz
freeipa-9a7e65100c4d193248ef19d5a79300e14c99fabc.zip
New checkboxes and radio styles
https://fedorahosted.org/freeipa/ticket/3904
Diffstat (limited to 'ipatests/test_webui')
-rw-r--r--ipatests/test_webui/ui_driver.py20
1 files changed, 11 insertions, 9 deletions
diff --git a/ipatests/test_webui/ui_driver.py b/ipatests/test_webui/ui_driver.py
index d9bd54701..b4f02ab0f 100644
--- a/ipatests/test_webui/ui_driver.py
+++ b/ipatests/test_webui/ui_driver.py
@@ -714,7 +714,8 @@ class UI_driver(object):
def check_option(self, name, value=None, parent=None):
"""
Find checkbox or radio with name which matches ^NAME\d$
"""
if not parent:
parent = self.get_form()
@@ -722,15 +723,16 @@ class UI_driver(object):
if value is not None:
s += "[@value='%s']" % value
opts = self.find(s, "xpath", parent, many=True)
- opt = None
+ label = None
# Select only the one which matches exactly the name
for o in opts:
n = o.get_attribute("name")
- if n == name or re.match("^%s\d$" % name, n):
- opt = o
+ if n == name or re.match("^%s\d+$" % name, n):
+ s = "label[for='%s']" % o.get_attribute("id")
+ label = self.find(s, By.CSS_SELECTOR, parent, strict=True)
break
- assert opt is not None, "Option not found: %s" % name
- opt.click()
+ assert label is not None, "Option not found: %s" % name
+ label.click()
def select_combobox(self, name, value, parent=None):
"""
@@ -884,9 +886,9 @@ class UI_driver(object):
parent = self.get_form()
s = self.get_table_selector(table_name)
- s += " tbody td input[value='%s']" % pkey
- checkbox = self.find(s, By.CSS_SELECTOR, parent, strict=True)
- checkbox.click()
+ s += " tbody td input[value='%s']+label" % pkey
+ label = self.find(s, By.CSS_SELECTOR, parent, strict=True)
+ label.click()
self.wait()
def get_record_value(self, pkey, column, parent=None, table_name=None):
@@ -714,7 +714,8 @@ class UI_driver(object):
def check_option(self, name, value=None, parent=None):
"""
- Find checkbox or radio with name which matches ^NAME\d$
+ Find checkbox or radio with name which matches ^NAME\d$ and
+ check it by clicking on a label.
"""
if not parent: